pub struct AgentContext<'a> { /* private fields */ }Expand description
Agent-scoped database context enforcing namespace isolation.
Created via db.as_agent(agent_id).
Implementations
Sourceimpl<'a> AgentContext<'a>
impl<'a> AgentContext<'a>
Sourcepub fn accessible_namespaces(&self) -> &[Namespace]
pub fn accessible_namespaces(&self) -> &[Namespace]
The namespaces accessible to this agent.
Sourcepub fn private_namespace(&self) -> Namespace
pub fn private_namespace(&self) -> Namespace
The agent’s private namespace.
Sourcepub fn can_access(&self, ns: &Namespace) -> bool
pub fn can_access(&self, ns: &Namespace) -> bool
Check whether this agent can access a given namespace.
Sourcepub async fn remember(&self, record: EpisodicRecord) -> HirnResult<MemoryId>
pub async fn remember(&self, record: EpisodicRecord) -> HirnResult<MemoryId>
Store an episodic record in the agent’s private namespace (default) or a specified namespace.
Sourcepub async fn remember_in(
&self,
record: EpisodicRecord,
namespace: Namespace,
) -> HirnResult<MemoryId>
pub async fn remember_in( &self, record: EpisodicRecord, namespace: Namespace, ) -> HirnResult<MemoryId>
Store a record explicitly in a named namespace.
Sourcepub fn recall(&self, query_embedding: Vec<f32>) -> AgentRecallBuilder<'_>
pub fn recall(&self, query_embedding: Vec<f32>) -> AgentRecallBuilder<'_>
Recall memories, searching only accessible namespaces. By default searches private + shared.
Sourcepub fn think(&self, query_embedding: Vec<f32>) -> AgentThinkBuilder<'_>
pub fn think(&self, query_embedding: Vec<f32>) -> AgentThinkBuilder<'_>
Think (context assembly) scoped to this agent’s accessible namespaces.
Sourcepub fn watch(&self, filter: WatchFilter) -> HirnResult<WatchSubscription>
pub fn watch(&self, filter: WatchFilter) -> HirnResult<WatchSubscription>
Create a watch subscription scoped to the agent’s accessible namespaces.
Sourcepub async fn inspect(&self, id: MemoryId) -> HirnResult<InspectResult>
pub async fn inspect(&self, id: MemoryId) -> HirnResult<InspectResult>
Inspect a record, verifying the agent has access to its namespace.
Sourcepub async fn trace(&self, id: MemoryId) -> HirnResult<TraceResult>
pub async fn trace(&self, id: MemoryId) -> HirnResult<TraceResult>
Trace a record, verifying the agent has access to its namespace.
Sourcepub async fn store_semantic(
&self,
record: SemanticRecord,
) -> HirnResult<MemoryId>
pub async fn store_semantic( &self, record: SemanticRecord, ) -> HirnResult<MemoryId>
Store a semantic record, enforcing namespace access.
Sourcepub async fn archive_episode(&self, id: MemoryId) -> HirnResult<()>
pub async fn archive_episode(&self, id: MemoryId) -> HirnResult<()>
Archive an episodic record, verifying namespace access.
Sourcepub async fn delete_episode(&self, id: MemoryId) -> HirnResult<()>
pub async fn delete_episode(&self, id: MemoryId) -> HirnResult<()>
Delete an episodic record, verifying namespace access.
Sourcepub async fn retract_semantic(
&self,
id: MemoryId,
retraction: SemanticRetraction,
) -> HirnResult<SemanticRecord>
pub async fn retract_semantic( &self, id: MemoryId, retraction: SemanticRetraction, ) -> HirnResult<SemanticRecord>
Retract a semantic record, verifying namespace access.
Sourcepub async fn override_semantic(
&self,
id: MemoryId,
override_request: SemanticOverride,
) -> HirnResult<SemanticRecord>
pub async fn override_semantic( &self, id: MemoryId, override_request: SemanticOverride, ) -> HirnResult<SemanticRecord>
Apply a durable semantic override, verifying namespace access.
Sourcepub async fn correct_semantic(
&self,
id: MemoryId,
update: SemanticUpdate,
) -> HirnResult<SemanticRecord>
pub async fn correct_semantic( &self, id: MemoryId, update: SemanticUpdate, ) -> HirnResult<SemanticRecord>
Correct a semantic record, verifying namespace access.
Sourcepub async fn supersede_semantic(
&self,
id: MemoryId,
supersession: SemanticSupersession,
) -> HirnResult<SemanticRecord>
pub async fn supersede_semantic( &self, id: MemoryId, supersession: SemanticSupersession, ) -> HirnResult<SemanticRecord>
Supersede a semantic record, verifying namespace access.
Sourcepub async fn merge_semantic(
&self,
target: MemoryId,
merge: SemanticMerge,
) -> HirnResult<SemanticMergeOutcome>
pub async fn merge_semantic( &self, target: MemoryId, merge: SemanticMerge, ) -> HirnResult<SemanticMergeOutcome>
Merge semantic logical memories, verifying namespace access for the target and sources.
Sourcepub async fn purge_semantic(&self, id: MemoryId) -> HirnResult<()>
pub async fn purge_semantic(&self, id: MemoryId) -> HirnResult<()>
Purge all revisions for a semantic logical memory, verifying namespace access.
Sourcepub async fn connect_with(
&self,
source: MemoryId,
target: MemoryId,
relation: EdgeRelation,
weight: f32,
metadata: Metadata,
) -> HirnResult<EdgeId>
pub async fn connect_with( &self, source: MemoryId, target: MemoryId, relation: EdgeRelation, weight: f32, metadata: Metadata, ) -> HirnResult<EdgeId>
Create a graph edge between two records, verifying namespace access for both.
Sourcepub async fn execute_ql(&self, query: &str) -> HirnResult<QueryResult>
pub async fn execute_ql(&self, query: &str) -> HirnResult<QueryResult>
Execute a HirnQL query scoped to the agent’s accessible namespaces.
Share a memory from this agent’s accessible namespaces to a target namespace.
Promote a private semantic record to the shared namespace.