pub async fn rollback(
storage: &dyn PhysicalStore,
tag: &str,
) -> Result<RollbackReport, HirnError>Expand description
Roll back all datasets to the versions captured by the named snapshot tag.
pub async fn rollback(
storage: &dyn PhysicalStore,
tag: &str,
) -> Result<RollbackReport, HirnError>Roll back all datasets to the versions captured by the named snapshot tag.