QueryBuilder

Struct QueryBuilder 

pub struct QueryBuilder<'a> { /* private fields */ }
Fluent builder for constructing HirnQL queries programmatically.

Implementations

Source

impl<'a> QueryBuilder<'a>

pub fn new(db: &'a HirnDB) -> Self

Create a new query builder bound to the given database.

pub fn recall(self, layers: &[Layer]) -> Self

Set the layers to query.

pub fn about(self, query: &str) -> Self

Set the semantic query string.

pub fn involving(self, entities: &[&str]) -> Self

Set the entities to involve.

pub fn modalities(self, modalities: &[ModalityProfile]) -> Self

Restrict recall results to specific content modalities.

pub fn resource_roles(self, roles: &[EvidenceRole]) -> Self

Restrict recall results to specific resource evidence roles.

pub fn hydration_modes(self, modes: &[HydrationMode]) -> Self

Restrict recall results to evidence that supports the requested hydration modes.

pub fn artifact_kinds(self, kinds: &[DerivedArtifactKind]) -> Self

Restrict recall results to specific derived artifact kinds.

pub fn after(self, ts: &str) -> Self

Filter records after a timestamp string (e.g. “2026-03-01”).

pub fn before(self, ts: &str) -> Self

Filter records before a timestamp string.

pub fn between(self, start: &str, end: &str) -> Self

Filter records between two timestamp strings.

pub fn expand_graph(self, depth: usize) -> Self

Enable graph expansion to the given depth.

pub fn min_weight(self, w: f32) -> Self

Set the minimum weight for graph expansion edges.

pub fn activation(self, mode: ActivationMode) -> Self

Set the activation mode for graph traversal.

pub fn follow_causes(self, depth: usize) -> Self

Follow causal chains to the given depth.

pub fn min_importance(self, threshold: f64) -> Self

Add a minimum importance filter.

pub fn min_confidence(self, threshold: f64) -> Self

Add a minimum confidence filter.

pub fn format(self, fmt: OutputFormat) -> Self

Set the output format.

pub fn budget(self, tokens: usize) -> Self

Set the token budget for context assembly.

pub fn namespace(self, ns: &str) -> Self

Restrict to a namespace.

pub fn consistency(self, level: ConsistencyLevel) -> Self

Set read consistency level.

pub fn limit(self, n: usize) -> Self

Set the maximum number of results.

pub fn context_config(self, config: ContextConfig) -> Self

Override the context assembly configuration for THINK queries.

pub fn build_recall_stmt(&self) -> Statement

Build the AST Statement that this builder represents as a RECALL.

pub fn build_think_stmt(&self) -> Statement

Build the AST Statement as a THINK.

pub fn plan(&self) -> QueryPlan

Get the query plan that would be executed (like EXPLAIN).

pub async fn execute(self) -> HirnResult<QueryResult>

Execute as a RECALL query.

pub async fn think(self) -> HirnResult<QueryResult>

Execute as a THINK query (with context assembly).